Class: Aws::PersonalizeEvents::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PersonalizeEvents::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-personalizeevents/client.rb
Overview
An API client for PersonalizeEvents. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PersonalizeEvents::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#put_action_interactions(params = {}) ⇒ Struct
Records action interaction event data.
-
#put_actions(params = {}) ⇒ Struct
Adds one or more actions to an Actions dataset.
-
#put_events(params = {}) ⇒ Struct
Records item interaction event data.
-
#put_items(params = {}) ⇒ Struct
Adds one or more items to an Items dataset.
-
#put_users(params = {}) ⇒ Struct
Adds one or more users to a Users dataset.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
744 745 746 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 744 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
747 748 749 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 747 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 717 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PersonalizeEvents') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-personalizeevents' context[:gem_version] = '1.72.0' Seahorse::Client::Request.new(handlers, context) end |
#put_action_interactions(params = {}) ⇒ Struct
Records action interaction event data. An *action interaction* event is an interaction between a user and an action. For example, a user taking an action, such a enrolling in a membership program or downloading your app.
For more information about recording action interactions, see [Recording action interaction events]. For more information about actions in an Actions dataset, see [Actions dataset].
[1]: docs.aws.amazon.com/personalize/latest/dg/recording-action-interaction-events.html [2]: docs.aws.amazon.com/personalize/latest/dg/actions-datasets.html
531 532 533 534 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 531 def put_action_interactions(params = {}, = {}) req = build_request(:put_action_interactions, params) req.send_request() end |
#put_actions(params = {}) ⇒ Struct
Adds one or more actions to an Actions dataset. For more information see [Importing actions individually].
[1]: docs.aws.amazon.com/personalize/latest/dg/importing-actions.html
568 569 570 571 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 568 def put_actions(params = {}, = {}) req = build_request(:put_actions, params) req.send_request() end |
#put_events(params = {}) ⇒ Struct
Records item interaction event data. For more information see [Recording item interaction events].
[1]: docs.aws.amazon.com/personalize/latest/dg/recording-item-interaction-events.html
634 635 636 637 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 634 def put_events(params = {}, = {}) req = build_request(:put_events, params) req.send_request() end |
#put_items(params = {}) ⇒ Struct
Adds one or more items to an Items dataset. For more information see [Importing items individually].
[1]: docs.aws.amazon.com/personalize/latest/dg/importing-items.html
671 672 673 674 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 671 def put_items(params = {}, = {}) req = build_request(:put_items, params) req.send_request() end |
#put_users(params = {}) ⇒ Struct
Adds one or more users to a Users dataset. For more information see [Importing users individually].
[1]: docs.aws.amazon.com/personalize/latest/dg/importing-users.html
708 709 710 711 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 708 def put_users(params = {}, = {}) req = build_request(:put_users, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
737 738 739 |
# File 'lib/aws-sdk-personalizeevents/client.rb', line 737 def waiter_names [] end |